import '../interface/libinterface.dart';
import '../model/cachingstrategy.dart';
import '../model/responsedata.dart';
import '../service/service.dart';
import '../sharepref/sharedpref.dart';

abstract class Repo with SharedPref, Service {
  Future<ResponseData?> getDataRepo() async {
    try {
      if (LibInterface.cachingStrategy == CachingStrategy.None) {
        //Network
        final data = await getDataNetwork(LibInterface.currentUserID, LibInterface.packageName);
        await setDataSavedTimeSP();
        await setDataSP(data);
        return data;
      }

      final lastSaved = await getDataSavedTimeSP();
      if (lastSaved == null) {
        //Network
        final data = await getDataNetwork(LibInterface.currentUserID, LibInterface.packageName);
        await setDataSavedTimeSP();
        await setDataSP(data);
        return data;
      }

      final lastDay = DateTime.now().add(LibInterface.cachingStrategy.getDuration());
      if ((lastDay.day - lastSaved.day) > LibInterface.cachingStrategy.getValue()) {
        //Network
        final data = await getDataNetwork(LibInterface.currentUserID, LibInterface.packageName);
        await setDataSavedTimeSP();
        await setDataSP(data);
        return data;
      }

      return await getDataSP();
    } catch (e) {
      rethrow;
    }
  }
}
